==> im-sdk_11.4.1483.orig.tar.gz: im-sdk-r11_4-1483/leif/newpy/GeneType.h <==
/*
Copyright 1990-2001 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/
/*
**  GeneType.h  GeneralType.h
**
**  Notes:     In Java, char is 16 bit; in cc of Solaris 2.6, 8 bits
*/

#ifndef _GENE_TYPE_H
#define _GENE_TYPE_H

#ifdef	__cplusplus
extern	"C" {
#endif

#define JSHORT	short
#define JINT	int
#define JFLOAT	float
#define JDOUBLE	double
#define JUINT	unsigned int
#define JUSHORT	unsigned short
#define JULONG  unsigned long
#define JLONG   long
#define JWORD   JUSHORT

#define CHAR	char
#define UCHAR	unsigned char
#define BYTE    unsigned char
#define VOID    void

#ifndef BOOL
#define BOOL    int
#endif
#ifndef TRUE
#define TRUE    1
#endif
#ifndef FALSE
#define FALSE   0
#endif

#ifndef min
#define min(a,b) (((a) < (b)) ? (a) : (b))
#endif
#ifndef max
#define max(a,b) (((a) > (b)) ? (a) : (b))
#endif

#define MALIGN  16    /* Memory Align constant, Used as a constant to malloc(). */

#ifdef	__cplusplus
}
#endif

#endif  /* _GENE_TYPE_H */

==> im-sdk_11.4.1870.orig.tar.gz: im-sdk-r11_4-1870/leif/newpy/GeneType.h <==
/*
Copyright 1990-2001 Sun Microsystems, Inc. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions: The above copyright notice and this
permission notice shall be included in all copies or substantial
portions of the Software.


THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE OPEN GROUP OR SUN MICROSYSTEMS, INC. BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE EVEN IF
ADVISED IN ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.


Except as contained in this notice, the names of The Open Group and/or
Sun Microsystems, Inc. shall not be used in advertising or otherwise to
promote the sale, use or other dealings in this Software without prior
written authorization from The Open Group and/or Sun Microsystems,
Inc., as applicable.


X Window System is a trademark of The Open Group

OSF/1, OSF/Motif and Motif are registered trademarks, and OSF, the OSF
logo, LBX, X Window System, and Xinerama are trademarks of the Open
Group. All other trademarks and registered trademarks mentioned herein
are the property of their respective owners. No right, title or
interest in or to any trademark, service mark, logo or trade name of
Sun Microsystems, Inc. or its licensors is granted.

*/
/*
**  GeneType.h  GeneralType.h
**
**  Notes:     In Java, char is 16 bit; in cc of Solaris 2.6, 8 bits
*/

#ifndef _GENE_TYPE_H
#define _GENE_TYPE_H

#ifdef	__cplusplus
extern	"C" {
#endif

#define JSHORT	short
#define JINT	int
#define JFLOAT	float
#define JDOUBLE	double
#define JUINT	unsigned int
#define JUSHORT	unsigned short
#define JULONG  unsigned long
#define JLONG   long
#define JWORD   JUSHORT

#define CHAR	char
#define UCHAR	unsigned char
#define BYTE    unsigned char
#define VOID    void

#ifndef BOOL
#define BOOL    int
#endif
#ifndef TRUE
#define TRUE    1
#endif
#ifndef FALSE
#define FALSE   0
#endif

#ifndef _MIN
#define _MIN(a,b) (((a) < (b)) ? (a) : (b))
#endif
#ifndef _MAX
#define _MAX(a,b) (((a) > (b)) ? (a) : (b))
#endif

#define MALIGN  16    /* Memory Align constant, Used as a constant to malloc(). */

#ifdef	__cplusplus
}
#endif

#endif  /* _GENE_TYPE_H */
